@@ -42,6 +42,8 @@
 #define GL_GLEXT_WUNDEF_SUPPORT
 
 #include <OpenGL/OpenGL.h>
+#include <OpenGL/gl.h>
+#include <OpenGL/glext.h>
 #include <OpenGL/CGLContext.h>
 
 /* These next few GL_EXT pre-processing blocks are to explicitly define 
@@ -167,7 +169,7 @@ void warn_func(void * p1, char *format, ...);
 
 // some prototypes
 static __GLXscreen * __glXAquaScreenProbe(ScreenPtr pScreen);
-static __GLXdrawable * __glXAquaScreenCreateDrawable(__GLXscreen *screen, DrawablePtr pDraw, int type, XID drawId, __GLXconfig *conf);
+static __GLXdrawable * __glXAquaScreenCreateDrawable(ClientPtr client, __GLXscreen *screen, DrawablePtr pDraw, XID drawId, int type, XID glxDrawId, __GLXconfig *conf);
 
 static void __glXAquaContextDestroy(__GLXcontext *baseContext);
 static int __glXAquaContextMakeCurrent(__GLXcontext *baseContext);
@@ -220,7 +222,7 @@ __glXAquaScreenCreateContext(__GLXscreen *screen,
   
     GLAQUA_DEBUG_MSG("glXAquaScreenCreateContext\n");
     
-    context = xcalloc(1, sizeof (__GLXAquaContext));
+    context = calloc(1, sizeof (__GLXAquaContext));
     
     if (context == NULL)
 	return NULL;
@@ -239,7 +241,7 @@ __glXAquaScreenCreateContext(__GLXscreen *screen,
     context->pixelFormat = makeFormat(conf);
     
     if (!context->pixelFormat) {
-        xfree(context);
+        free(context);
         return NULL;
     }
 
@@ -251,7 +253,7 @@ __glXAquaScreenCreateContext(__GLXscreen *screen,
     if (gl_err != 0) {
 	ErrorF("CGLCreateContext error: %s\n", CGLErrorString(gl_err));
 	CGLDestroyPixelFormat(context->pixelFormat);
-	xfree(context);
+	free(context);
 	return NULL;
     }
     
@@ -284,7 +286,7 @@ static void __glXAquaContextDestroy(__GLXcontext *baseContext) {
       if (context->pixelFormat != NULL)
 	  CGLDestroyPixelFormat(context->pixelFormat);
       
-      xfree(context);
+      free(context);
     }
 }
 
@@ -548,7 +550,7 @@ static CGLPixelFormatObj makeFormat(__GLXconfig *conf) {
        attr[i++] = conf->samples;
     }
      
-    attr[i + 1] = 0;
+    attr[i] = 0;
 
     error = CGLChoosePixelFormat(attr, &fobj, &formats);
     if(error) {
@@ -564,7 +566,7 @@ static void __glXAquaScreenDestroy(__GLXscreen *screen) {
     GLAQUA_DEBUG_MSG("glXAquaScreenDestroy(%p)\n", screen);
     __glXScreenDestroy(screen);
 
-    xfree(screen);
+    free(screen);
 }
 
 /* This is called by __glXInitScreens(). */
@@ -576,7 +578,7 @@ static __GLXscreen * __glXAquaScreenProbe(ScreenPtr pScreen) {
     if (pScreen == NULL) 
 	return NULL;
 
-    screen = xcalloc(1, sizeof *screen);
+    screen = calloc(1, sizeof *screen);
 
     if(NULL == screen)
 	return NULL;
@@ -593,12 +595,12 @@ static __GLXscreen * __glXAquaScreenProbe(ScreenPtr pScreen) {
 
     __glXScreenInit(&screen->base, pScreen);
 
-    screen->base.GLXversion = xstrdup("1.4");
-    screen->base.GLXextensions = xstrdup("GLX_SGIX_fbconfig "
-					 "GLX_SGIS_multisample "
-					 "GLX_ARB_multisample "
-					 "GLX_EXT_visual_info "
-					 "GLX_EXT_import_context ");
+    screen->base.GLXversion = strdup("1.4");
+    screen->base.GLXextensions = strdup("GLX_SGIX_fbconfig "
+                                        "GLX_SGIS_multisample "
+                                        "GLX_ARB_multisample "
+                                        "GLX_EXT_visual_info "
+                                        "GLX_EXT_import_context ");
     
     /*We may be able to add more GLXextensions at a later time. */
     
@@ -633,26 +635,28 @@ static void __glXAquaDrawableDestroy(__GLXdrawable *base) {
      *to validate the test, beyond using gdb with print.
      */
 
-    xfree(glxPriv);
+    free(glxPriv);
 }
 
 static __GLXdrawable *
-__glXAquaScreenCreateDrawable(__GLXscreen *screen,
+__glXAquaScreenCreateDrawable(ClientPtr client,
+                              __GLXscreen *screen,
 			      DrawablePtr pDraw,
-			      int type,
 			      XID drawId,
+			      int type,
+			      XID glxDrawId,
 			      __GLXconfig *conf) {
   __GLXAquaDrawable *glxPriv;
 
-  glxPriv = xalloc(sizeof *glxPriv);
+  glxPriv = malloc(sizeof *glxPriv);
 
   if(glxPriv == NULL)
       return NULL;
 
   memset(glxPriv, 0, sizeof *glxPriv);
 
-  if(!__glXDrawableInit(&glxPriv->base, screen, pDraw, type, drawId, conf)) {
-    xfree(glxPriv);
+  if(!__glXDrawableInit(&glxPriv->base, screen, pDraw, type, glxDrawId, conf)) {
+    free(glxPriv);
     return NULL;
   }
 
