@@ -74,14 +74,14 @@ SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
 #include <AvailabilityMacros.h>
 
-static int DRIScreenPrivKeyIndex;
-static DevPrivateKey DRIScreenPrivKey = &DRIScreenPrivKeyIndex;
-static int DRIWindowPrivKeyIndex;
-static DevPrivateKey DRIWindowPrivKey = &DRIWindowPrivKeyIndex;
-static int DRIPixmapPrivKeyIndex;
-static DevPrivateKey DRIPixmapPrivKey = &DRIPixmapPrivKeyIndex;
-static int DRIPixmapBufferPrivKeyIndex;
-static DevPrivateKey DRIPixmapBufferPrivKey = &DRIPixmapBufferPrivKeyIndex;
+static DevPrivateKeyRec DRIScreenPrivKeyRec;
+#define DRIScreenPrivKey (&DRIScreenPrivKeyRec)
+static DevPrivateKeyRec DRIWindowPrivKeyRec;
+#define DRIWindowPrivKey (&DRIWindowPrivKeyRec)
+static DevPrivateKeyRec DRIPixmapPrivKeyRec;
+#define DRIPixmapPrivKey (&DRIPixmapPrivKeyRec)
+static DevPrivateKeyRec DRIPixmapBufferPrivKeyRec;
+#define DRIPixmapBufferPrivKey (&DRIPixmapBufferPrivKeyRec)
 
 static RESTYPE DRIDrawablePrivResType;
 
@@ -205,7 +205,16 @@ DRIScreenInit(ScreenPtr pScreen)
     DRIScreenPrivPtr    pDRIPriv;
     int                 i;
 
-    pDRIPriv = (DRIScreenPrivPtr) xcalloc(1, sizeof(DRIScreenPrivRec));
+    if (!dixRegisterPrivateKey(&DRIScreenPrivKeyRec, PRIVATE_SCREEN, 0))
+	return FALSE;
+    if (!dixRegisterPrivateKey(&DRIWindowPrivKeyRec, PRIVATE_WINDOW, 0))
+	return FALSE;
+    if (!dixRegisterPrivateKey(&DRIPixmapPrivKeyRec, PRIVATE_PIXMAP, 0))
+	return FALSE;
+    if (!dixRegisterPrivateKey(&DRIPixmapBufferPrivKeyRec, PRIVATE_PIXMAP, 0))
+	return FALSE;
+
+    pDRIPriv = (DRIScreenPrivPtr) calloc(1, sizeof(DRIScreenPrivRec));
     if (!pDRIPriv) {
 	dixSetPrivate(&pScreen->devPrivates, DRIScreenPrivKey, NULL);
         return FALSE;
@@ -269,7 +278,7 @@ DRICloseScreen(ScreenPtr pScreen)
     DRIScreenPrivPtr pDRIPriv = DRI_SCREEN_PRIV(pScreen);
 
     if (pDRIPriv && pDRIPriv->directRenderingSupport) {
-        xfree(pDRIPriv);
+        free(pDRIPriv);
 	dixSetPrivate(&pScreen->devPrivates, DRIScreenPrivKey, NULL);
     }
 }
@@ -280,7 +289,7 @@ DRIExtensionInit(void)
     DRIDrawablePrivResType = CreateNewResourceType(DRIDrawablePrivDelete,
 						   "DRIDrawable");
 
-    return (DRIDrawablePrivResType != 0);
+    return DRIDrawablePrivResType != 0;
 }
 
 void
@@ -347,8 +356,8 @@ DRIUpdateSurface(DRIDrawablePrivPtr pDRIDrawablePriv, DrawablePtr pDraw)
         wc.height = pWin->drawable.height + 2 * pWin->borderWidth;
         wc.bit_gravity = XP_GRAVITY_NONE;
 
-        wc.shape_nrects = REGION_NUM_RECTS(&pWin->clipList);
-        wc.shape_rects = REGION_RECTS(&pWin->clipList);
+        wc.shape_nrects = RegionNumRects(&pWin->clipList);
+        wc.shape_rects = RegionRects(&pWin->clipList);
         wc.shape_tx = - (pTopWin->drawable.x - pTopWin->borderWidth);
         wc.shape_ty = - (pTopWin->drawable.y - pTopWin->borderWidth);
 
@@ -381,7 +390,7 @@ CreateSurfaceForWindow(ScreenPtr pScreen, WindowPtr pWin, xp_window_id *widPtr)
 	xp_window_changes wc;
 	
 	/* allocate a DRI Window Private record */
-	if (!(pDRIDrawablePriv = xalloc(sizeof(*pDRIDrawablePriv)))) {
+	if (!(pDRIDrawablePriv = malloc(sizeof(*pDRIDrawablePriv)))) {
 	    return NULL;
 	}
 	
@@ -395,7 +404,7 @@ CreateSurfaceForWindow(ScreenPtr pScreen, WindowPtr pWin, xp_window_id *widPtr)
 	wid = x_cvt_vptr_to_uint(RootlessFrameForWindow(pWin, TRUE));
 
 	if (wid == 0) {
-	    xfree(pDRIDrawablePriv);
+	    free(pDRIDrawablePriv);
 	    return NULL;
 	}
 	
@@ -403,7 +412,7 @@ CreateSurfaceForWindow(ScreenPtr pScreen, WindowPtr pWin, xp_window_id *widPtr)
 	err = xp_create_surface(wid, &pDRIDrawablePriv->sid);
 
 	if (err != Success) {
-	    xfree(pDRIDrawablePriv);
+	    free(pDRIDrawablePriv);
 	    return NULL;
 	}
 
@@ -414,7 +423,7 @@ CreateSurfaceForWindow(ScreenPtr pScreen, WindowPtr pWin, xp_window_id *widPtr)
 
 	if (err != Success) {
 	    xp_destroy_surface(pDRIDrawablePriv->sid);
-	    xfree(pDRIDrawablePriv);
+	    free(pDRIDrawablePriv);
 	    return NULL;
 	}
 
@@ -439,7 +448,7 @@ CreateSurfaceForPixmap(ScreenPtr pScreen, PixmapPtr pPix) {
 	xp_error err;
 
 	/* allocate a DRI Window Private record */
-	if (!(pDRIDrawablePriv = xcalloc(1, sizeof(*pDRIDrawablePriv)))) {
+	if (!(pDRIDrawablePriv = calloc(1, sizeof(*pDRIDrawablePriv)))) {
 	    return NULL;
 	}
 	
@@ -454,7 +463,7 @@ CreateSurfaceForPixmap(ScreenPtr pScreen, PixmapPtr pPix) {
 	
 	err = xp_create_surface(0, &pDRIDrawablePriv->sid);
 	if (err != Success) {
-	    xfree(pDRIDrawablePriv);
+	    free(pDRIDrawablePriv);
 	    return NULL;
 	}
 
@@ -519,7 +528,7 @@ DRICreateSurface(ScreenPtr pScreen, Drawable id,
                                     client_id, key);
             if (err != Success) {
                 xp_destroy_surface(pDRIDrawablePriv->sid);
-                xfree(pDRIDrawablePriv);
+                free(pDRIDrawablePriv);
 		
 		/* 
 		 * Now set the dix privates to NULL that were previously set.
@@ -637,7 +646,7 @@ DRIDrawablePrivDelete(pointer pResource, XID id)
     if (pDRIDrawablePriv->notifiers != NULL)
         x_hook_free(pDRIDrawablePriv->notifiers);
 
-    xfree(pDRIDrawablePriv);
+    free(pDRIDrawablePriv);
 
     if (pDrawable->type == DRAWABLE_WINDOW) {
 	dixSetPrivate(&pWin->devPrivates, DRIWindowPrivKey, NULL);
@@ -828,7 +837,7 @@ Bool DRICreatePixmap(ScreenPtr pScreen, Drawable id,
 
     pPix = (PixmapPtr)pDrawable;
 
-    shared = xalloc(sizeof(*shared));
+    shared = malloc(sizeof(*shared));
     if(NULL == shared) {
         FatalError("failed to allocate DRIPixmapBuffer in %s\n", __func__);
     }
@@ -856,7 +865,7 @@ Bool DRICreatePixmap(ScreenPtr pScreen, Drawable id,
                           S_IRUSR | S_IWUSR | S_IROTH | S_IWOTH);
     
     if(-1 == shared->fd) {
-	xfree(shared);
+	free(shared);
         return FALSE;
     }   
     
@@ -866,7 +875,7 @@ Bool DRICreatePixmap(ScreenPtr pScreen, Drawable id,
 	ErrorF("failed to ftruncate (extend) file.");
 	shm_unlink(shared->shmPath);
 	close(shared->fd);
-	xfree(shared);
+	free(shared);
 	return FALSE;
     }
 
@@ -878,7 +887,7 @@ Bool DRICreatePixmap(ScreenPtr pScreen, Drawable id,
 	ErrorF("failed to mmap shared memory.");
 	shm_unlink(shared->shmPath);
 	close(shared->fd);
-	xfree(shared);
+	free(shared);
 	return FALSE;
     }
     
@@ -938,7 +947,7 @@ DRIFreePixmapImp(DrawablePtr pDrawable) {
     close(shared->fd);
     munmap(shared->buffer, shared->length);
     shm_unlink(shared->shmPath);
-    xfree(shared);
+    free(shared);
 
     dixSetPrivate(&pPix->devPrivates, DRIPixmapBufferPrivKey, (pointer)NULL);
 
